@@ -468,7 +468,7 @@ class CastepCalculation(CalcJob, CastepInputGenerator):
         time_str = time.strftime("%H:%M:%S %d/%m/%Y %Z")
         lines = [
             "##### Generated by aiida_castep {} #####".format(time_str),
-            "#         author: Bonan Zhu (bz240@cam.ac.uk)",
+            "#         author: Bonan Zhu (zhubonan@outlook.com)",
             "# "
             "# AiiDA User: {}".format(
                 orm.User.objects.get_default().get_full_name()),
