@@ -464,17 +464,20 @@ def nested_update_dict_node(dict_node, update_dict):
 
 @calcfunction
 def seekpath_structure_analysis(structure, **kwargs):
-    """Primitivize the structure with SeeKpath and generate the high symmetry k-point path through its Brillouin zone.
+    """
+    Primitivize the structure with SeeKpath and generate the high symmetry k-point path through its Brillouin zone.
     This calcfunction will take a structure and pass it through SeeKpath to get the normalized primitive cell and the
     path of high symmetry k-points through its Brillouin zone. Note that the returned primitive cell may differ from the
     original structure in which case the k-points are only congruent with the primitive cell.
     The keyword arguments can be used to specify various Seekpath parameters, such as:
+
         with_time_reversal: True
         reference_distance: 0.025
         recipe: 'hpkot'
         threshold: 1e-07
         symprec: 1e-05
         angle_tolerance: -1.0
+
     Note that exact parameters that are available and their defaults will depend on your Seekpath version.
     """
 
